import subprocess
from logger import get_logger
from os import path

lg = get_logger(__name__)


_KUBE_CONFIG = path.expanduser("~/.kube/config")


def invoke_command(cmd_list):
    lg.info("Invoke command: %s", cmd_list)
    p = subprocess.Popen(cmd_list, stdout=subprocess.PIPE,
                         stderr=subprocess.PIPE)
    out, err = p.communicate()
    # In Python3, communicate() returns byte strings, so convert to string
    if out is not None:
        out = out.decode("utf8")
    if err is not None:
        err = err.decode("utf8")
    rc = p.returncode
    status_log = ("Command: %r executed with rc: %d\nerr: %s\nout: %s\n" %
                  (cmd_list, rc, err, out))
    if rc:
        lg.error(status_log)
        raise RuntimeError("Command %r wasn't executed successfully" %
                           cmd_list)
    lg.info("Invoke command: rc: %s\nout:%s\nerr:%s", rc, out, err)
    return rc, out, err


def set_kubectl(kubeconf):
    if kubeconf:
        if path.isfile(path.expanduser(kubeconf)):
            global _KUBE_CONFIG
            _KUBE_CONFIG = path.expanduser(kubeconf)
        else:
            raise RuntimeError("%s does't exist or is not a regular file" %
                               kubeconf)


def kubectl_command(cmd):
    kubectl = r"kubectl --kubeconfig " + _KUBE_CONFIG
    return invoke_command(kubectl.split() + cmd.split())


