#!/bin/bash
set -o errexit
set -o pipefail
set -o nounset

if [[ -z "${KUBECONFIG:-}" ]]; then
    export KUBECONFIG=/config/vmware/napps/.kube/config
fi

# clean old logs
rm -rf /var/log/napps/* || true

timestamp=$(date +%s)
namespaces=$(kubectl get ns -o=jsonpath='{.items[*].metadata.name}')
logDir=/var/log/napps/$timestamp

mkdir -p $logDir

# collect nodes status
kubectl get nodes -o wide >$logDir/nodes_status

# collect namespaces status
kubectl get ns -oyaml >$logDir/ns_status

# collect pods status
kubectl get pods -A -o wide >$logDir/pods_status

for ns in $namespaces; do
    subLogDir=$logDir/$ns
    mkdir -p $subLogDir
    # describe all resources
    kubectl describe all -n $ns >$subLogDir/resources_status || true
    # collect all logs
    pods=$(kubectl get pods -n $ns -o=jsonpath='{.items[*].metadata.name}')
    for pod in $pods; do
        kubectl logs $pod -n $ns --all-containers=true >$subLogDir/$pod || true
        kubectl logs -p $pod -n $ns --all-containers=true >$subLogDir/$pod-previous || true
    done
done
