# Constants


class Certificate:
    service_type = "K8S_MSG_CLIENT"
    # k8s_msg_client certificate attributes
    display_name = "message bus client for NSX Application platform"
    algorithm = "RSA"
    key_size = "2048"
    subject = {
        "attributes": [
            {"key": "CN", "value": "k8s-msg-client"},
            {"key": "O", "value": "VMware Inc."},
            {"key": "OU", "value": "NSX"},
            {"key": "L", "value": "Palo Alto"},
            {"key": "ST", "value": "CA"},
            {"key": "C", "value": "US"},
        ]
    }


# PORTs
PRTON_PORT = 7440
NAPI_PORT = 7441

# API URIs on manager side
GET_AAA_ROLE_BINDING = "/nsxapi/api/v1/aaa/role-bindings"
GET_CLUSTER_CERT = "/nsxapi/api/v1/trust-management/certificates?details" \
                   "=true&&type=cluster_api_certificate"
GET_CLUSTER_CERT_WITH_PRIVATE_KEY = "/nsxapi/api/v1/trust-management" \
                                    "/certificates/<id>?action=get_private"
GET_CERT_ID = "/nsxapi/api/v1/trust-management/certificates/<id>"
GET_DEPLOYMENT_REGISTRY = "/nsxapi/api/v1/infra/sites/default/napp/deployment/registry"
GET_ALL_CERTS = "/nsxapi/api/v1/trust-management/certificates"
GET_NSX_NODE_VERSION = "/api/v1/node"
GET_PI_CERTS = "/nsxapi/api/v1/trust-management/principal-identities"
DELETE_PI = "/nsxapi/api/v1/trust-management/principal-identities/<id>"
DELETE_CERT = "/nsxapi/api/v1/trust-management/certificates/<id>"
POST_REGISTER_PI_CERT = "/nsxapi/api/v1/trust-management/" \
                        "principal-identities/with-certificate"
POST_APPLY_KAFKA_CLIENT_CERT = "/nsxapi/api/v1/trust-management/certificates" \
                               "/<id>?action=apply_certificate&service_type" \
                               "=K8S_MSG_CLIENT"
RELEASE_USED_CERTIFICATE = "/nsxapi/api/v1/trust-management/certificates/<id" \
                           ">?action=release"
POST_GENERATE_CSR = "/nsxapi/api/v1/trust-management/csrs"
POST_SELF_SIGN_CSR = "/nsxapi/api/v1/trust-management/csrs/<id>?action" \
                     "=self_sign&days_valid=825"
DELETE_CSR = "/nsxapi/api/v1/trust-management/csrs/<id>"

# API URIs on cloud native platform side
GET_CLOUDNATIVE_PLATFORM_CERTS = "/napp/api/v1/platform/trust" \
                                 "-management/certificates"
POST_CLOUDNATIVE_PLATFROM_CERT = "/napp/api/v1/platform/trust" \
                                 "-management/certificates"
GET_PLATFORM_HEALTH = "/napp/api/v1/platform/monitor/platform/status"
GET_FEATURES_INTELLIGENCE_CONFIG = "/napp/api/v1/platform/features" \
                                   "/intelligence/config"
NAPP_CERT_EGRESS_ENTITIES = {"NAPP_PLATFORM_EGRESS"}
NAPP_CERT_NONEGRESS_ENTITIES = {"NAPP_PLATFORM_INGRESS",
                                "NAPP_PLATFORM_KAFKA"}

# HELM CA constants
NAPP_HELM_CA_ALIAS = "NsxHelmCA"
USED_BY_NAPP_HELM_CA = "NAPP_HELM_CA"

# FILE PATHs
WORK_DIR = "./tmp/"
PRIVATE_KEY_PATH = WORK_DIR + "tls.key"
PUBLIC_CERT_PATH = WORK_DIR + "tls.crt"
NAPP_PLATFORM_CA_PATH = WORK_DIR + "ca.crt"
HELM_CA_41X_WORKAROUND_FILENAME = "/usr/local/share/ca-certificates/harbor_ca.crt"

#NSX Compatibilty file name
COMPATIBILITY_FILE = 'nsx-platform-compatibility.cfg'

# load-default-site job related constants
# must match activeDeadlineSeconds defined for job load-default-site here:
# https://gitlab-vmw.devops.broadcom.net/core-build/nsx-pace/-/blob/c29c3df1b33a0f1814ebecfafcbc9f2529742470/platform/helm-charts/site-service/templates/job-load-default-site.yaml#L12
TIMEOUT_SECS_LOAD_SITE = "600s"
